@@ -1,4 +1,4 @@
-page <- html("http://www.sejm.gov.pl/Sejm7.nsf/wypowiedz.xsp?posiedzenie=15&dzien=1&wyp=0")
+page <- read_html("http://www.sejm.gov.pl/Sejm7.nsf/wypowiedz.xsp?posiedzenie=15&dzien=1&wyp=0")
 page <- html_nodes(page, ".stenogram")
 statements_links <- html_nodes(page, "h2 a")
 
